@@ -5,14 +5,12 @@ Zabbix::Check - Zabbix Agent system and service checks
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
 Zabbix Agent system and service checks
 
-=head1 USAGE
-
 =head2 Disk
 
 Zabbix check for disk
@@ -137,7 +135,7 @@ BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.02';
+	our $VERSION     = '1.03';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
@@ -202,8 +200,9 @@ sub printDiscovery
 				my %newitem = map({
 					my $key = $_;
 					my $val = $item->{$key};
-					my $newkey = uc("{#$key}");
-					my $newval = $val;
+					my $newkey = zbxEncode($key);
+					$newkey = uc("{#$newkey}");
+					my $newval = zbxEncode($val);
 					$newkey => $newval;
 				} keys(%$item));
 				\%newitem;
@@ -218,7 +217,7 @@ sub printDiscovery
 sub whereisBin
 {
 	my ($name) = @_;
-	return grep(-f $_, map("$_/$name", split(":", "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin")));
+	return grep(-x $_, map("$_/$name", split(":", "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin")));
 }
 
 
@@ -227,6 +226,12 @@ die "OS '$osname' is not supported" unless $osname eq 'linux';
 
 1;
 __END__
+=head1 REPOSITORY
+
+B<GitHub> L<https://github.com/orkunkaraduman/Zabbix-Check>
+
+B<CPAN> L<https://metacpan.org/pod/Zabbix::Check>
+
 =head1 AUTHOR
 
 Orkun Karaduman <orkunkaraduman@gmail.com>
